# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import DataNavigator
from .Grid import IPlottableGrid
from .Toolbar import IToolbarsManager

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MetricsPlot

class MetricsPlotControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotPane,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    PlotControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MetricsPlot.PlotControl
    )  # readonly
    PlottableGrid: Agilent.MassHunter.Quantitative.UIModel.IPlottableGrid  # readonly
    ShowAverageStdDevLines: bool

    def GetActivePaneData(
        self,
    ) -> Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotData: ...

class PlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    DataNavigator: DataNavigator
    PlottableGrid: IPlottableGrid
    ShowAverageStdDevLines: bool
    ToolbarsManager: IToolbarsManager

    def GetAutoScaleRangeX(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetActivePaneData(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.MetricsPlot.PlotData: ...

class PlotData(
    Agilent.MassSpectrometry.GUI.Plot.IPeakData,
    Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotData,
    Agilent.MassSpectrometry.GUI.Plot.IPlotData,
):  # Class
    AutoScale: bool
    NextColor: System.Drawing.Color  # readonly

    def AutoScaleY(self) -> None: ...
    def Clear(self) -> None: ...
    def AddSeries(self, columnName: str, color: System.Drawing.Color) -> None: ...
    def AutoScaleX(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    DefaultEventManipulatorBase,
    IMarkerData,
    IPeakData,
    IPlotData,
    IPlotDataAxisAssoc,
    PlotModes,
)

# Stubs for namespace: Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser

class ChromPlotData(
    Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.PlotData,
    IPeakData,
    System.IDisposable,
    IPlotDataAxisAssoc,
    IPlotData,
):  # Class
    def __init__(self) -> None: ...

    PeakList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.IChromPeak
    ]

    def Dispose(self) -> None: ...

class DefaultEventManipulator(
    DefaultEventManipulatorBase,
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
):  # Class
    def __init__(
        self, context: Agilent.MassSpectrometry.EventManipulating.EventContext
    ) -> None: ...
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseMove(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...

class FDDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class FDProgressDlg(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.MainForm,
        totalNumScanRecords: int,
    ) -> None: ...

class GoToDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Rt: float  # readonly
    ScanIndex: int  # readonly
    UseRT: bool  # readonly

class MainForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    MassCalOptions: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalibrationOptions
    )  # readonly
    StatusText: str

    @staticmethod
    def ShowError(msg: str) -> None: ...
    @staticmethod
    def ShowMessage(msg: str) -> None: ...

class OptionsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, mainForm: Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.MainForm
    ) -> None: ...

    ApplyMassStepFiltering: bool
    CentroidType: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidType
    DoMassCal: bool
    InterpolationType: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.InterpolationType
    )
    MaxRefMzDelta: float
    MinFoundRefMZsForTradFit: int
    MinFoundRefMZsPerRange: int
    ReferenceMassFilePath: str
    ResolveShoulderPeaks: bool
    WriteApexList: bool
    WriteHistogram: bool
    WriteMassCalResults: bool
    WritePeakShapes: bool
    WriteRefMzResiduals: bool

class PlotData(System.IDisposable, IPlotData, IPlotDataAxisAssoc):  # Class
    def __init__(self) -> None: ...
    def GetPointCount(self, series: int) -> int: ...
    def GetSeriesCount(self) -> int: ...
    def DisplaySeries(self, series: int) -> bool: ...
    def RemoveSeries(self, index: int) -> None: ...
    def GetPoint(self, series: int, pointIndex: int, x: float, y: float) -> None: ...
    def GetYRange(self, minY: float, maxY: float) -> None: ...
    def AddSeries(
        self,
        color: System.Drawing.Color,
        mode: PlotModes,
        points: List[System.Drawing.PointF],
    ) -> None: ...
    def GetXRange(self, minX: float, maxX: float) -> None: ...
    def Dispose(self) -> None: ...
    def GetSeriesLineStyle(
        self,
        series: int,
        mode: PlotModes,
        color: System.Drawing.Color,
        style: System.Drawing.Drawing2D.DashStyle,
        width: int,
    ) -> None: ...

class ProgressDlg(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.MainForm,
        totalNumScanRecords: int,
    ) -> None: ...

class RidgeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        ridgeInfo: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeFeatureInfo,
    ) -> None: ...

class RidgePlotData(
    Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.PlotData,
    IPeakData,
    System.IDisposable,
    IPlotDataAxisAssoc,
    IPlotData,
):  # Class
    def __init__(
        self,
        ridge: Agilent.MassSpectrometry.DataAnalysis.FD.Ridge,
        features: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FD.Feature
        ],
    ) -> None: ...

    ShowFeatureFlightTimes: bool

    def Dispose(self) -> None: ...

class SpectrumPlotData(
    Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.PlotData,
    IPeakData,
    System.IDisposable,
    IPlotDataAxisAssoc,
    IPlotData,
):  # Class
    def __init__(self) -> None: ...

    PeakList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrumPeak
    ]

    def Dispose(self) -> None: ...

class TICPlotData(
    Agilent.MassSpectrometry.GUI.Plot.TofDataBrowser.PlotData,
    System.IDisposable,
    IPlotDataAxisAssoc,
    IPlotData,
    IMarkerData,
):  # Class
    def __init__(
        self,
        dataNavigator: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SampleDataNavigator,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .PlotControl import Axis, IAxisContainer

# Stubs for namespace: Agilent.MassHunter.Quantitative.HeatMap

class HeatMapControl(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    IAxisContainer,
    System.Windows.Controls.Control,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    InternalMarginChanged: System.EventHandler
    MonochromeProperty: System.Windows.DependencyProperty  # static # readonly

    AxisX: Axis  # readonly
    AxisY: Axis  # readonly
    Data: Agilent.MassHunter.Quantitative.HeatMap.IHeatMapData
    Monochrome: bool

    def RecalcRects(self) -> None: ...
    def CreateTypeface(self) -> System.Windows.Media.Typeface: ...
    def GetImageMargin(self) -> System.Windows.Thickness: ...
    def GetRenderingPoint(self, x: float, y: float) -> System.Windows.Point: ...
    def GetDataPoint(self, x: float, y: float) -> System.Windows.Point: ...
    def GetGraphicsRect(self) -> System.Windows.Rect: ...
    def Invalidate(self) -> None: ...

class IHeatMapData(object):  # Interface
    MaxValue: float  # readonly
    MaxX: float  # readonly
    MaxY: float  # readonly
    MinValue: float  # readonly
    MinX: float  # readonly
    MinY: float  # readonly
    XCount: int  # readonly
    YCount: int  # readonly

    def GetValue(self, x: int, y: int) -> float: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.PlotControl3D

class Bar3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(
        self, x0: float, y0: float, z0: float, W: float, L: float, H: float
    ) -> None: ...
    def SetMesh(self) -> None: ...
    def SetData(
        self, x0: float, y0: float, z0: float, W: float, L: float, H: float
    ) -> None: ...

class Chart3D:  # Class
    def __init__(self) -> None: ...

    SHAPE_NO: int  # static
    m_axisColor: System.Windows.Media.Color

    def __getitem__(
        self, n: int
    ) -> Agilent.MassHunter.Quantitative.PlotControl3D.Vertex3D: ...
    def __setitem__(
        self, n: int, value_: Agilent.MassHunter.Quantitative.PlotControl3D.Vertex3D
    ) -> None: ...
    def ZMin(self) -> float: ...
    def AddAxesMeshes(self, meshs: System.Collections.ArrayList) -> None: ...
    def HighlightSelection(
        self,
        meshGeometry: System.Windows.Media.Media3D.MeshGeometry3D,
        selectColor: System.Windows.Media.Color,
    ) -> None: ...
    def XMin(self) -> float: ...
    def YCenter(self) -> float: ...
    def ZRange(self) -> float: ...
    @overload
    def SetAxes(
        self, x0: float, y0: float, z0: float, xL: float, yL: float, zL: float
    ) -> None: ...
    @overload
    def SetAxes(self) -> None: ...
    @overload
    def SetAxes(self, margin: float) -> None: ...
    def YRange(self) -> float: ...
    def GetDataRange(self) -> None: ...
    def XRange(self) -> float: ...
    def YMax(self) -> float: ...
    def Select(
        self,
        rect: Agilent.MassHunter.Quantitative.PlotControl3D.ViewportRect,
        matrix: Agilent.MassHunter.Quantitative.PlotControl3D.TransformMatrix,
        viewport3d: System.Windows.Controls.Viewport3D,
    ) -> None: ...
    def XCenter(self) -> float: ...
    def YMin(self) -> float: ...
    def GetDataNo(self) -> int: ...
    def ZMax(self) -> float: ...
    def XMax(self) -> float: ...
    def SetDataNo(self, nSize: int) -> None: ...

    # Nested Types

    class SHAPE(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
        BAR: Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D.SHAPE = (
            ...
        )  # static # readonly
        CONE: Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D.SHAPE = (
            ...
        )  # static # readonly
        CYLINDER: Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D.SHAPE = (
            ...
        )  # static # readonly
        ELLIPSE: Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D.SHAPE = (
            ...
        )  # static # readonly
        PYRAMID: Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D.SHAPE = (
            ...
        )  # static # readonly

class ColorMesh3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(self) -> None: ...
    def GetColor(self, nV: int) -> System.Windows.Media.Color: ...
    def SetVertexNo(self, nSize: int) -> None: ...
    @overload
    def SetColor(self, nV: int, r: int, g: int, b: int) -> None: ...
    @overload
    def SetColor(self, nV: int, color: System.Windows.Media.Color) -> None: ...

class Cone3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(self, a: float, b: float, h: float, nRes: int) -> None: ...

class Cylinder3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(self, a: float, b: float, h: float, nRes: int) -> None: ...

class Ellipse3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(self, a: float, b: float, h: float, nRes: int) -> None: ...

class Mesh3D:  # Class
    def __init__(self) -> None: ...

    m_xMax: float
    m_xMin: float
    m_yMax: float
    m_yMin: float
    m_zMax: float
    m_zMin: float

    @overload
    def SetPoint(self, n: int, pt: System.Windows.Media.Media3D.Point3D) -> None: ...
    @overload
    def SetPoint(self, n: int, x: float, y: float, z: float) -> None: ...
    @overload
    def SetColor(self, r: int, g: int, b: int) -> None: ...
    @overload
    def SetColor(self, color: System.Windows.Media.Color) -> None: ...
    def SetSize(self, nVertexNo: int, nTriangleNo: int) -> None: ...
    def GetTriangle(
        self, n: int
    ) -> Agilent.MassHunter.Quantitative.PlotControl3D.Triangle3D: ...
    def GetTriangleNo(self) -> int: ...
    def GetPoint(self, n: int) -> System.Windows.Media.Media3D.Point3D: ...
    def GetColor(self, nV: int) -> System.Windows.Media.Color: ...
    def SetVertexNo(self, nSize: int) -> None: ...
    def GetTriangleNormal(self, n: int) -> System.Windows.Media.Media3D.Vector3D: ...
    @overload
    def SetTriangle(
        self, n: int, triangle: Agilent.MassHunter.Quantitative.PlotControl3D.Triangle3D
    ) -> None: ...
    @overload
    def SetTriangle(self, i: int, m0: int, m1: int, m2: int) -> None: ...
    def SetTriangleNo(self, nSize: int) -> None: ...
    def UpdatePositions(
        self, meshGeometry: System.Windows.Media.Media3D.MeshGeometry3D
    ) -> None: ...
    def SetTestModel(self) -> None: ...
    def GetVertexNo(self) -> int: ...

class Model3D(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Media3D.ModelVisual3D,
    System.Windows.Media.Composition.DUCE.IResource,
    MS.Internal.IVisual3DContainer,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def SetPsedoColor(self) -> None: ...
    def SetRGBColor(self) -> None: ...
    def UpdateModel(
        self,
        meshs: System.Collections.ArrayList,
        backMaterial: System.Windows.Media.Media3D.Material,
        nModelIndex: int,
        viewport3d: System.Windows.Controls.Viewport3D,
    ) -> int: ...
    @staticmethod
    def GetGeometry(
        viewport3d: System.Windows.Controls.Viewport3D, nModelIndex: int
    ) -> System.Windows.Media.Media3D.MeshGeometry3D: ...

class Pyramid3D(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    @overload
    def __init__(self, size: float) -> None: ...
    @overload
    def __init__(self, W: float, L: float, H: float) -> None: ...
    def SetData(self, W: float, L: float, H: float) -> None: ...

class ScatterChart3D(Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D):  # Class
    def __init__(self) -> None: ...
    def HighlightSelection(
        self,
        meshGeometry: System.Windows.Media.Media3D.MeshGeometry3D,
        selectColor: System.Windows.Media.Color,
    ) -> None: ...
    def Get(
        self, n: int
    ) -> Agilent.MassHunter.Quantitative.PlotControl3D.ScatterPlotItem: ...
    def GetMeshes(self) -> System.Collections.ArrayList: ...
    def Select(
        self,
        rect: Agilent.MassHunter.Quantitative.PlotControl3D.ViewportRect,
        matrix: Agilent.MassHunter.Quantitative.PlotControl3D.TransformMatrix,
        viewport3d: System.Windows.Controls.Viewport3D,
    ) -> None: ...
    def SetVertex(
        self,
        n: int,
        value_: Agilent.MassHunter.Quantitative.PlotControl3D.ScatterPlotItem,
    ) -> None: ...

class ScatterPlotItem(Agilent.MassHunter.Quantitative.PlotControl3D.Vertex3D):  # Class
    def __init__(self) -> None: ...

    h: float
    shape: int
    w: float

class SurfaceChart3D(Agilent.MassHunter.Quantitative.PlotControl3D.Chart3D):  # Class
    def __init__(self) -> None: ...
    def HighlightSelection(
        self,
        meshGeometry: System.Windows.Media.Media3D.MeshGeometry3D,
        selectColor: System.Windows.Media.Color,
    ) -> None: ...
    def Select(
        self,
        rect: Agilent.MassHunter.Quantitative.PlotControl3D.ViewportRect,
        matrix: Agilent.MassHunter.Quantitative.PlotControl3D.TransformMatrix,
        viewport3d: System.Windows.Controls.Viewport3D,
    ) -> None: ...

class TextureMapping:  # Class
    def __init__(self) -> None: ...

    m_material: System.Windows.Media.Media3D.DiffuseMaterial

    @overload
    @staticmethod
    def GetMappingPosition(
        color: System.Windows.Media.Color,
    ) -> System.Windows.Point: ...
    @overload
    @staticmethod
    def GetMappingPosition(
        color: System.Windows.Media.Color, bPseudoColor: bool
    ) -> System.Windows.Point: ...
    @staticmethod
    def PseudoColor(k: float) -> System.Windows.Media.Color: ...
    def SetRGBMaping(self) -> None: ...
    def SetPseudoMaping(self) -> None: ...

class TransformMatrix:  # Class
    def __init__(self) -> None: ...

    m_scaleFactor: float
    m_totalMatrix: System.Windows.Media.Media3D.Matrix3D

    def RotateView(self, q: System.Windows.Media.Media3D.Quaternion) -> None: ...
    def OnLBtnDown(self, pt: System.Windows.Point) -> None: ...
    @overload
    def CalculateProjectionMatrix(
        self,
        mesh: Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D,
        scaleFactor: float,
    ) -> None: ...
    @overload
    def CalculateProjectionMatrix(
        self, min: float, max: float, scaleFactor: float
    ) -> None: ...
    @overload
    def CalculateProjectionMatrix(
        self,
        xMin: float,
        xMax: float,
        yMin: float,
        yMax: float,
        zMin: float,
        zMax: float,
        scaleFactor: float,
    ) -> None: ...
    def OnMouseMove(
        self, pt: System.Windows.Point, viewPort: System.Windows.Controls.Viewport3D
    ) -> None: ...
    def OnLBtnUp(self) -> None: ...
    def OnKeyDown(self, args: System.Windows.Input.KeyEventArgs) -> None: ...
    @overload
    @staticmethod
    def Transform(
        pt1: System.Windows.Media.Media3D.Point3D,
        center: System.Windows.Media.Media3D.Point3D,
        aX: float,
        aZ: float,
    ) -> System.Windows.Media.Media3D.Point3D: ...
    @overload
    @staticmethod
    def Transform(
        model: Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D,
        center: System.Windows.Media.Media3D.Point3D,
        aX: float,
        aZ: float,
    ) -> None: ...
    @staticmethod
    def ScreenPtToViewportPt(
        point: System.Windows.Point, viewPort: System.Windows.Controls.Viewport3D
    ) -> System.Windows.Point: ...
    def ResetView(self) -> None: ...
    def VertexToScreenPt(
        self,
        point: System.Windows.Media.Media3D.Point3D,
        viewPort: System.Windows.Controls.Viewport3D,
    ) -> System.Windows.Point: ...
    def VertexToViewportPt(
        self,
        point: System.Windows.Media.Media3D.Point3D,
        viewPort: System.Windows.Controls.Viewport3D,
    ) -> System.Windows.Point: ...

class Triangle3D:  # Class
    def __init__(self, m0: int, m1: int, m2: int) -> None: ...

    n0: int
    n1: int
    n2: int

class UniformSurfaceChart3D(
    Agilent.MassHunter.Quantitative.PlotControl3D.SurfaceChart3D
):  # Class
    def __init__(self) -> None: ...
    def SetPoint(self, i: int, j: int, x: float, y: float, z: float) -> None: ...
    def SetColor(self, i: int, j: int, color: System.Windows.Media.Color) -> None: ...
    def GetMeshes(self) -> System.Collections.ArrayList: ...
    def SetGrid(
        self, xNo: int, yNo: int, xMin: float, xMax: float, yMin: float, yMax: float
    ) -> None: ...
    def SetZ(self, i: int, j: int, z: float) -> None: ...

class Vertex3D:  # Class
    def __init__(self) -> None: ...

    color: System.Windows.Media.Color
    nMaxI: int
    nMinI: int
    selected: bool
    x: float
    y: float
    z: float

class ViewportRect(Agilent.MassHunter.Quantitative.PlotControl3D.Mesh3D):  # Class
    def __init__(self) -> None: ...

    m_lineWidth: float
    m_zLevel: float

    def OnMouseDown(
        self,
        pt: System.Windows.Point,
        viewport3d: System.Windows.Controls.Viewport3D,
        nModelIndex: int,
    ) -> None: ...
    def XMin(self) -> float: ...
    def YMax(self) -> float: ...
    def GetMeshes(self) -> System.Collections.ArrayList: ...
    def OnMouseMove(
        self,
        pt: System.Windows.Point,
        viewport3d: System.Windows.Controls.Viewport3D,
        nModelIndex: int,
    ) -> None: ...
    def SetRect(self, pt1: System.Windows.Point, pt2: System.Windows.Point) -> None: ...
    def YMin(self) -> float: ...
    def XMax(self) -> float: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Themes.Wizard

class IWizardContentViewModel(object):  # Interface
    BackButtonCommand: System.Windows.Input.ICommand  # readonly
    BackButtonContent: str  # readonly
    BackButtonVisibility: System.Windows.Visibility  # readonly
    CancelButtonCommand: System.Windows.Input.ICommand  # readonly
    CancelButtonContent: str  # readonly
    CancelButtonVisibility: System.Windows.Visibility  # readonly
    Content: Any  # readonly
    FinishButtonCommand: System.Windows.Input.ICommand  # readonly
    FinishButtonContent: str  # readonly
    FinishButtonVisibility: System.Windows.Visibility  # readonly
    IsEnabled: bool  # readonly
    Label: str  # readonly
    NextButtonCommand: System.Windows.Input.ICommand  # readonly
    NextButtonContent: str  # readonly
    NextButtonVisibility: System.Windows.Visibility  # readonly
    Title: str  # readonly

class IWizardWindowModel(object):  # Interface
    CurrentViewModel: Any
    NavigationSubTitle: str  # readonly
    NavigationTitle: str  # readonly
    ViewModels: List[Any]  # readonly
    WindowTitle: str  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import IChromatogram, IChromPeak, IMsMsChromPeak, IPeakList

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator

class AgileConfig:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, timeSegments: List[float], smoothingKernelSize: int) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        smoothingKernelSize: int,
        resolvePeaksByShape: bool,
    ) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        dataHasGaps: bool,
        smoothingKernelSize: int,
        resolvePeaksByShape: bool,
    ) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        smoothingKernelSize: int,
        peakShape: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape,
    ) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        dataHasGaps: bool,
        smoothingKernelSize: int,
        peakShape: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape,
    ) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        smoothingKernelSize: int,
        peakShape: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape,
        noiseFactor2: float,
    ) -> None: ...
    @overload
    def __init__(
        self,
        timeSegments: List[float],
        smoothingKernelSize: int,
        peakShape: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape,
        noiseFactor2: float,
        keepEdgeApexInMedianFilter: bool,
    ) -> None: ...

    VERSION_1: int = ...  # static # readonly
    VERSION_2: int = ...  # static # readonly

    DataHasGaps: bool  # readonly
    KeepEdgeApexInMedianFilter: bool
    NoiseFactor2: float  # readonly
    PeakShape: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape
    )  # readonly
    ResolvePeaksByShape: bool  # readonly
    SmoothingKernelSize: int  # readonly
    TimeSegments: List[float]  # readonly
    Version: int  # readonly

class AgilePeakShape:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, peak: IChromPeak, chrom: IChromatogram) -> None: ...

    ApexIndex: int  # readonly
    FWHM: float  # readonly
    InterpolatedApexX: float  # readonly
    InterpolatedApexY: float  # readonly
    IsEquallySpaced: bool  # readonly
    PointCount: int  # readonly
    XArray: List[float]  # readonly
    XAverageStep: float  # readonly
    YArray: List[float]  # readonly

    @staticmethod
    def Base64ToDoubleArray(str: str) -> List[float]: ...
    def Parse(self, str: str) -> None: ...
    def DebugWrite(self, sw: System.IO.StreamWriter) -> None: ...
    def ToCsvString(self) -> str: ...
    def AlignApexAndInterpolateShape(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakShape: ...
    @staticmethod
    def DoubleArrayToBase64(dValues: List[float]) -> str: ...

class AgilePeakStatus(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    HeightProblem: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    ) = ...  # static # readonly
    InterferenceProblem: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    ) = ...  # static # readonly
    MergeProblem: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    ) = ...  # static # readonly
    OK: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus = (
        ...
    )  # static # readonly
    Spiky: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus = (
        ...
    )  # static # readonly
    SymmetryProblem: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    ) = ...  # static # readonly
    WidthProblem: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    ) = ...  # static # readonly

class BaselineRegionInfo:  # Class
    End: int  # readonly
    LowestIndex: int  # readonly
    Merged: bool  # readonly
    Start: int  # readonly

class BaselineSegment:  # Class
    CenterX: float  # readonly
    End: int  # readonly
    HighestIndex: int  # readonly
    Index: int  # readonly
    IsOutlier: bool  # readonly
    Length: int  # readonly
    LowestIndex: int  # readonly
    MaxY: float  # readonly
    MinY: float  # readonly
    NRuns: int  # readonly
    Start: int  # readonly
    YMean: float  # readonly
    YVariance: float  # readonly

    def Contains(self, index: int) -> bool: ...
    def SetOutlier(self) -> None: ...

class CompatibleSort:  # Class
    @staticmethod
    def Sort40(
        list: System.Collections.Generic.List[T],
        comparer: System.Collections.Generic.IComparer[T],
    ) -> None: ...

class CompatibleSort40(Generic[T]):  # Class
    ...

class IPeakListProvider(object):  # Interface
    def SetBaselineOffset(self, peakList: IPeakList, baselineOffset: float) -> None: ...
    def SetSaturationFlag(self, peak: IMsMsChromPeak, saturated: bool) -> None: ...
    def MakeChromPeak(self) -> IMsMsChromPeak: ...
    def MakeChromPeakList(self) -> IPeakList: ...
    def SetBaselineStdDev(self, peakList: IPeakList, baselineStdDev: float) -> None: ...

class LocalIntegrator:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, config: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgileConfig
    ) -> None: ...

    AssumeNoisyTSBoundaries: bool  # static
    BaselineNoiseAmplitude: float  # readonly
    LeftTailingFactor: float  # static
    LowTailingFactor: float  # static
    NoiseAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.NoiseAnalysis
    )  # readonly
    NoiseFactorSquared: float  # readonly
    PrettyTails: bool  # static
    ScaledBaselineNoiseAmplitude2: float  # readonly
    ScaledNoiseFactorSquared: float  # readonly
    TailingFactor: float  # static
    YMax: float  # readonly
    YMin: float  # readonly

    def GetBaselineSegments(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.BaselineSegment
    ]: ...
    def GetNoiseFactor(self, xArray: List[float], yArray: List[float]) -> float: ...
    @overload
    def SplitPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
    ) -> IPeakList: ...
    @overload
    def SplitPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        timeSegments: List[float],
        smoothingKernelSize: int,
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
    ) -> IPeakList: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        timeSegments: List[float],
        smoothingKernelSize: int,
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
    ) -> IPeakList: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        config: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgileConfig,
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
    ) -> IPeakList: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        timeSegments: List[float],
        smoothingKernelSize: int,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.Peak
    ]: ...
    @overload
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        config: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgileConfig,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.Peak
    ]: ...

class MedianFilter:  # Class
    def __init__(self) -> None: ...
    @overload
    @staticmethod
    def Apply3PointFilter(signal: List[float]) -> None: ...
    @overload
    @staticmethod
    def Apply3PointFilter(signal: List[int]) -> None: ...
    @overload
    @staticmethod
    def Apply3PointFilter(signal: List[T]) -> None: ...
    @staticmethod
    def KeepMaxApexAtEdge(
        yInput: List[float], yFiltered: List[float], yMax: float
    ) -> None: ...
    @staticmethod
    def KeepEdgeApex(yInput: List[float], yFiltered: List[float]) -> None: ...

class NoiseAnalysis:  # Class
    Runs: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.Run
    ]  # readonly

    def FindRunByEndPosition(self, endPointIndex: int) -> int: ...
    def GetRunByIndex(
        self, runIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.Run: ...

class Peak:  # Class
    AgilePeakStatus: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.AgilePeakStatus
    )  # readonly
    Apex: int  # readonly
    Area: float  # readonly
    Base1End: float  # readonly
    Base1Start: float  # readonly
    Base2End: float  # readonly
    Base2Start: float  # readonly
    BaselineSlope: float  # readonly
    CenterX: float  # readonly
    EndBaselineY: float  # readonly
    EndIndex: int  # readonly
    EndX: float  # readonly
    EndY: float  # readonly
    FullWidthHalfMaximum: float  # readonly
    Height: float  # readonly
    IsSaturated: bool  # readonly
    LeftBaselineRegion: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.BaselineRegionInfo
    )  # readonly
    LeftEdgeIndex: int  # readonly
    MaxY: float  # readonly
    RightBaselineRegion: (
        Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.BaselineRegionInfo
    )  # readonly
    RightEdgeIndex: int  # readonly
    StartBaselineY: float  # readonly
    StartIndex: int  # readonly
    StartX: float  # readonly
    StartY: float  # readonly
    Symmetry: float  # readonly
    YBaselineOffset: float  # readonly
    YIntercept: float  # readonly

    @overload
    @staticmethod
    def DoManualIntegration(
        manualPeak: IMsMsChromPeak,
        xArray: List[float],
        yArray: List[float],
        x1: float,
        x2: float,
        y1: float,
        y2: float,
        integrator: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.LocalIntegrator,
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
        peakList: IPeakList,
    ) -> None: ...
    @overload
    @staticmethod
    def DoManualIntegration(
        xArray: List[float],
        yArray: List[float],
        x1: float,
        x2: float,
        y1: float,
        y2: float,
        integrator: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.LocalIntegrator,
        peakListProvider: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.IPeakListProvider,
        peakList: IPeakList,
    ) -> IMsMsChromPeak: ...
    @overload
    @staticmethod
    def DoManualIntegration(
        xArray: List[float],
        yArray: List[float],
        x1: float,
        x2: float,
        y1: float,
        y2: float,
        integrator: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.LocalIntegrator,
        peakList: IPeakList,
    ) -> Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.Peak: ...
    def ConvertToChromPeak(self, chromPeak: IMsMsChromPeak) -> None: ...
    @staticmethod
    def UpdateMIBaselineRegions(
        xArray: List[float],
        yArray: List[float],
        x1: float,
        x2: float,
        y1: float,
        y2: float,
        manualPeak: IMsMsChromPeak,
        peakList: IPeakList,
    ) -> None: ...
    @staticmethod
    def ComputeChromatographicMetrics(
        xArray: List[float],
        yArray: List[float],
        startIndex: int,
        apexIndex: int,
        endIndex: int,
        baselineSlope: float,
        yIntercept: float,
        fullWidthHalfMaximum: float,
        symmetry: float,
    ) -> None: ...

class Run:  # Class
    End: int  # readonly
    Length: int  # readonly
    RunType: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.RunType  # readonly
    Start: int  # readonly
    YBottom: float  # readonly
    YDelta: float  # readonly
    YMidPoint: float  # readonly
    YTop: float  # readonly

class RunType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Down: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.RunType = (
        ...
    )  # static # readonly
    Flat: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.RunType = (
        ...
    )  # static # readonly
    Up: Agilent.MassSpectrometry.DataAnalysis.AgileIntegrator.RunType = (
        ...
    )  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Template

class Body(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IBody,
):  # Class
    def __init__(self) -> None: ...

    Items: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    _Items: List[Agilent.MassHunter.ReportBuilder.Template.ReportItem]

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class Borders(Agilent.MassHunter.ReportBuilder.Template.IBorders):  # Class
    def __init__(self) -> None: ...

    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    _Bottom: Agilent.MassHunter.ReportBuilder.Template.Line
    _Left: Agilent.MassHunter.ReportBuilder.Template.Line
    _Right: Agilent.MassHunter.ReportBuilder.Template.Line
    _Top: Agilent.MassHunter.ReportBuilder.Template.Line

class BreakLocation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Between: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    BetweenEvery2nd: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    BetweenEvery3rd: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    End: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    Start: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    StartAndBetween: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly
    StartAndEnd: Agilent.MassHunter.ReportBuilder.Template.BreakLocation = (
        ...
    )  # static # readonly

class Color(Agilent.MassHunter.ReportBuilder.Template.IColor):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, color: Agilent.MassHunter.ReportBuilder.Template.IColor
    ) -> None: ...
    @overload
    def __init__(self, color: System.Drawing.Color) -> None: ...
    @overload
    def __init__(self, a: int, r: int, g: int, b: int) -> None: ...
    @overload
    def __init__(self, value_: str) -> None: ...

    A: int  # readonly
    B: int  # readonly
    Default: Agilent.MassHunter.ReportBuilder.Template.Color  # static # readonly
    G: int  # readonly
    R: int  # readonly
    Value: str

    def ToString(self) -> str: ...

class DataBinding(Agilent.MassHunter.ReportBuilder.Template.IDataBinding):  # Class
    def __init__(self) -> None: ...

    BindingName: str
    DataBindings: List[
        Agilent.MassHunter.ReportBuilder.Template.IDataBinding
    ]  # readonly
    DataName: str
    Expression: str
    Filters: List[Agilent.MassHunter.ReportBuilder.Template.IDataFilter]  # readonly
    GroupBy: str
    LeftOuterJoin: bool
    Orders: List[Agilent.MassHunter.ReportBuilder.Template.IDataOrder]  # readonly
    ProcessThisLayer: bool
    _DataBindings: List[Agilent.MassHunter.ReportBuilder.Template.DataBinding]
    _Filters: List[Agilent.MassHunter.ReportBuilder.Template.DataFilter]
    _Orders: List[Agilent.MassHunter.ReportBuilder.Template.DataOrder]

class DataFilter(Agilent.MassHunter.ReportBuilder.Template.IDataFilter):  # Class
    def __init__(self) -> None: ...

    ConcatenationType: (
        Agilent.MassHunter.ReportBuilder.Template.DataFilterConcatenationType
    )
    FieldName: str
    FieldValue: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    Operator: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator
    Value: str
    _FieldValue: Agilent.MassHunter.ReportBuilder.Template.FieldValue

class DataFilterConcatenationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    And: Agilent.MassHunter.ReportBuilder.Template.DataFilterConcatenationType = (
        ...
    )  # static # readonly
    Or: Agilent.MassHunter.ReportBuilder.Template.DataFilterConcatenationType = (
        ...
    )  # static # readonly

class DataFilterOperator(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BelongToGroup: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    CloseParenthesis: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    Contains: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    Equals: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    Greater: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    GreaterEqual: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    IsNull: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    Less: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    LessEqual: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    NotEquals: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    NotNull: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    OpenParenthesis: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator = (
        ...
    )  # static # readonly

class DataOrder(Agilent.MassHunter.ReportBuilder.Template.IDataOrder):  # Class
    def __init__(self) -> None: ...

    Ascending: bool
    FieldName: str

class DefaultFont(
    Agilent.MassHunter.ReportBuilder.Template.IFont,
    Agilent.MassHunter.ReportBuilder.Template.Font,
    Agilent.MassHunter.ReportBuilder.Template.IDefaultFont,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        culture: str,
        name: str,
        size: Optional[float],
        italic: Optional[bool],
        strikeout: Optional[bool],
        underline: Optional[bool],
        bold: Optional[bool],
    ) -> None: ...

    Culture: str

class FieldValue(Agilent.MassHunter.ReportBuilder.Template.IFieldValue):  # Class
    def __init__(self) -> None: ...

    BindingName: str
    FieldName: str

class Font(Agilent.MassHunter.ReportBuilder.Template.IFont):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        size: Optional[float],
        italic: Optional[bool],
        strikeout: Optional[bool],
        underline: Optional[bool],
        bold: Optional[bool],
    ) -> None: ...

    Bold: Optional[bool]
    Italic: Optional[bool]
    Name: str
    Size: Optional[float]
    Strikeout: Optional[bool]
    Underline: Optional[bool]

    # Nested Types

    class _Scriptable:  # Class
        Bold: Optional[bool]
        Italic: Optional[bool]
        Name: str
        Size: Optional[float]
        Strikeout: Optional[bool]
        Underline: Optional[bool]

class Footer(
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IHeaderFooter,
    Agilent.MassHunter.ReportBuilder.Template.IFooter,
    Agilent.MassHunter.ReportBuilder.Template.HeaderFooter,
):  # Class
    def __init__(self) -> None: ...

class Graphics(
    Agilent.MassHunter.ReportBuilder.Template.IGraphics,
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Class
    def __init__(self) -> None: ...

    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Name: str
    Parameters: List[
        Agilent.MassHunter.ReportBuilder.Template.IGraphicsParameter
    ]  # readonly
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    WidthPercentage: float
    _Height: Agilent.MassHunter.ReportBuilder.Template.Length
    _Parameters: List[Agilent.MassHunter.ReportBuilder.Template.GraphicsParameter]
    _Width: Agilent.MassHunter.ReportBuilder.Template.Length

class GraphicsParameter(
    Agilent.MassHunter.ReportBuilder.Template.IGraphicsParameter
):  # Class
    def __init__(self) -> None: ...

    FieldValue: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    Name: str
    Value: str
    _FieldValue: Agilent.MassHunter.ReportBuilder.Template.FieldValue

class Header(
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IHeaderFooter,
    Agilent.MassHunter.ReportBuilder.Template.HeaderFooter,
    Agilent.MassHunter.ReportBuilder.Template.IHeader,
):  # Class
    def __init__(self) -> None: ...

class HeaderFooter(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IHeaderFooter,
):  # Class
    def __init__(self) -> None: ...

    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Borders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    Center: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    Right: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    _BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.Color
    _Borders: Agilent.MassHunter.ReportBuilder.Template.Borders
    _Center: List[Agilent.MassHunter.ReportBuilder.Template.ReportItem]
    _Height: Agilent.MassHunter.ReportBuilder.Template.Length
    _Left: List[Agilent.MassHunter.ReportBuilder.Template.ReportItem]
    _Right: List[Agilent.MassHunter.ReportBuilder.Template.ReportItem]

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class HorizontalAlign(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Center: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign = (
        ...
    )  # static # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign = (
        ...
    )  # static # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign = (
        ...
    )  # static # readonly

class IBody(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Items: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly

class IBorders(object):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILine  # readonly

class IColor(object):  # Interface
    A: int  # readonly
    B: int  # readonly
    G: int  # readonly
    R: int  # readonly

class IDataBinding(object):  # Interface
    BindingName: str  # readonly
    DataBindings: List[
        Agilent.MassHunter.ReportBuilder.Template.IDataBinding
    ]  # readonly
    DataName: str  # readonly
    Expression: str  # readonly
    Filters: List[Agilent.MassHunter.ReportBuilder.Template.IDataFilter]  # readonly
    GroupBy: str  # readonly
    LeftOuterJoin: bool  # readonly
    Orders: List[Agilent.MassHunter.ReportBuilder.Template.IDataOrder]  # readonly
    ProcessThisLayer: bool  # readonly

class IDataFilter(object):  # Interface
    ConcatenationType: (
        Agilent.MassHunter.ReportBuilder.Template.DataFilterConcatenationType
    )  # readonly
    FieldName: str  # readonly
    FieldValue: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    Operator: Agilent.MassHunter.ReportBuilder.Template.DataFilterOperator  # readonly
    Value: str  # readonly

class IDataOrder(object):  # Interface
    Ascending: bool  # readonly
    FieldName: str  # readonly

class IDefaultFont(Agilent.MassHunter.ReportBuilder.Template.IFont):  # Interface
    Culture: str  # readonly

class IFieldValue(object):  # Interface
    BindingName: str  # readonly
    FieldName: str  # readonly

class IFont(object):  # Interface
    Bold: Optional[bool]  # readonly
    Italic: Optional[bool]  # readonly
    Name: str  # readonly
    Size: Optional[float]  # readonly
    Strikeout: Optional[bool]  # readonly
    Underline: Optional[bool]  # readonly

class IFooter(
    Agilent.MassHunter.ReportBuilder.Template.IHeaderFooter,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Interface
    ...

class IGraphics(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Name: str  # readonly
    Parameters: List[
        Agilent.MassHunter.ReportBuilder.Template.IGraphicsParameter
    ]  # readonly
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    WidthPercentage: float  # readonly

class IGraphicsParameter(object):  # Interface
    FieldValue: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    Name: str  # readonly
    Value: str  # readonly

class IHeader(
    Agilent.MassHunter.ReportBuilder.Template.IHeaderFooter,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Interface
    ...

class IHeaderFooter(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Borders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    Center: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    Right: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly

class IImage(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    File: str  # readonly
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    LockAspectRatio: bool  # readonly
    VerticalAlign: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign  # readonly
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly

class ILength(object):  # Interface
    def ValueAs(
        self, unit: Agilent.MassHunter.ReportBuilder.Template.LengthUnit
    ) -> float: ...

class ILine(object):  # Interface
    Color: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Style: Agilent.MassHunter.ReportBuilder.Template.LineStyle  # readonly
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly

class IList(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    DataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding  # readonly
    Hidden: bool  # readonly
    Items: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    PageBreak: Agilent.MassHunter.ReportBuilder.Template.BreakLocation  # readonly

class ILocalizableFieldValue(
    Agilent.MassHunter.ReportBuilder.Template.IFieldValue
):  # Interface
    Localize: bool  # readonly

class IMargins(object):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly

class IPaddings(object):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly

class IPage(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Body: Agilent.MassHunter.ReportBuilder.Template.IBody  # readonly
    Footer: Agilent.MassHunter.ReportBuilder.Template.IFooter  # readonly
    Header: Agilent.MassHunter.ReportBuilder.Template.IHeader  # readonly
    Margins: Agilent.MassHunter.ReportBuilder.Template.IMargins  # readonly
    Orientation: Agilent.MassHunter.ReportBuilder.Template.PageOrientation  # readonly

class IPrintGraphicsSettings(object):  # Interface
    FitToSheet: bool
    FitToSheetWidth: bool
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength
    UseTemplateSettings: bool
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength

class IReportItem(object):  # Interface
    ID: str  # readonly
    Scriptable: Agilent.MassHunter.ReportBuilder.Template.IScriptable  # readonly

class IReportTemplate(
    Agilent.MassHunter.ReportBuilder.Template.IReportItem
):  # Interface
    AppVersion: str  # readonly
    Copyright: str  # readonly
    DefaultFonts: List[
        Agilent.MassHunter.ReportBuilder.Template.IDefaultFont
    ]  # readonly
    DesignerType: str  # readonly
    EditorVersion: str  # readonly
    Pages: List[Agilent.MassHunter.ReportBuilder.Template.IPage]  # readonly
    SchemaVersion: int  # readonly
    TextSets: Agilent.MassHunter.ReportBuilder.Template.ITextSets  # readonly

class IScriptBox(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Script: str

class IScriptable(object):  # Interface
    ...

class ITable(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Columns: List[Agilent.MassHunter.ReportBuilder.Template.ITableColumn]  # readonly
    DataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding  # readonly
    DefaultCellBorders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    Flow: bool  # readonly
    HeaderRows: int  # readonly
    Hidden: bool  # readonly
    HorizontalAlign: (
        Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign
    )  # readonly
    KeepTogether: bool  # readonly
    PageBreak: Agilent.MassHunter.ReportBuilder.Template.BreakLocation  # readonly
    Rows: List[Agilent.MassHunter.ReportBuilder.Template.ITableRow]  # readonly
    SpacingBefore: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    WidthPercentage: float  # readonly

class ITableCell(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Borders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    ColumnSpan: int  # readonly
    Content: Agilent.MassHunter.ReportBuilder.Template.IReportItem  # readonly

class ITableColumn(object):  # Interface
    RelativeWidth: float  # readonly

class ITableRow(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    Cells: List[Agilent.MassHunter.ReportBuilder.Template.ITableCell]  # readonly

class ITextSet(object):  # Interface
    ID: str  # readonly
    TextValues: List[Agilent.MassHunter.ReportBuilder.Template.ITextValue]  # readonly

class ITextSets(object):  # Interface
    Texts: List[Agilent.MassHunter.ReportBuilder.Template.ITextSet]  # readonly

class ITextValue(object):  # Interface
    Culture: str  # readonly
    Value: str  # readonly

class ITextbox(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Interface
    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Color: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    ContentType: Optional[
        Agilent.MassHunter.ReportBuilder.Template.TextboxContentType
    ]  # readonly
    Expression: str
    FieldCaption: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    FieldFormat: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    FieldValue: (
        Agilent.MassHunter.ReportBuilder.Template.ILocalizableFieldValue
    )  # readonly
    Font: Agilent.MassHunter.ReportBuilder.Template.IFont  # readonly
    Format: str
    HorizontalAlign: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign
    LocalizedText: str
    OutlineLevel: Optional[int]
    Paddings: Agilent.MassHunter.ReportBuilder.Template.IPaddings  # readonly
    Text: str
    VerticalAlign: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign

class Image(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IImage,
):  # Class
    def __init__(self) -> None: ...

    File: str
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    LockAspectRatio: bool
    VerticalAlign: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    _Height: Agilent.MassHunter.ReportBuilder.Template.Length
    _Width: Agilent.MassHunter.ReportBuilder.Template.Length

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class Length(Agilent.MassHunter.ReportBuilder.Template.ILength):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, value_: float, unit: Agilent.MassHunter.ReportBuilder.Template.LengthUnit
    ) -> None: ...
    @overload
    def __init__(
        self, length: Agilent.MassHunter.ReportBuilder.Template.Length
    ) -> None: ...

    Centimeter: float
    Inch: float
    Millimeter: float
    Point: float
    Presentation: float
    Unit: Agilent.MassHunter.ReportBuilder.Template.LengthUnit
    Value: float
    XmlValue: str

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, len: Agilent.MassHunter.ReportBuilder.Template.Length) -> bool: ...
    def ValueAs(
        self, unit: Agilent.MassHunter.ReportBuilder.Template.LengthUnit
    ) -> float: ...
    def GetHashCode(self) -> int: ...
    def Parse(self, value_: str, ci: System.Globalization.CultureInfo) -> None: ...
    @overload
    def ToString(self) -> str: ...
    @overload
    def ToString(self, ci: System.Globalization.CultureInfo) -> str: ...

class LengthUnit(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Centimeter: Agilent.MassHunter.ReportBuilder.Template.LengthUnit = (
        ...
    )  # static # readonly
    Inch: Agilent.MassHunter.ReportBuilder.Template.LengthUnit = (
        ...
    )  # static # readonly
    Millimeter: Agilent.MassHunter.ReportBuilder.Template.LengthUnit = (
        ...
    )  # static # readonly
    Point: Agilent.MassHunter.ReportBuilder.Template.LengthUnit = (
        ...
    )  # static # readonly
    Presentation: Agilent.MassHunter.ReportBuilder.Template.LengthUnit = (
        ...
    )  # static # readonly

class Line(Agilent.MassHunter.ReportBuilder.Template.ILine):  # Class
    def __init__(self) -> None: ...

    Color: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Style: Agilent.MassHunter.ReportBuilder.Template.LineStyle
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    _Color: Agilent.MassHunter.ReportBuilder.Template.Color
    _Width: Agilent.MassHunter.ReportBuilder.Template.Length

class LineStyle(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Dash: Agilent.MassHunter.ReportBuilder.Template.LineStyle = ...  # static # readonly
    Dot: Agilent.MassHunter.ReportBuilder.Template.LineStyle = ...  # static # readonly
    Solid: Agilent.MassHunter.ReportBuilder.Template.LineStyle = (
        ...
    )  # static # readonly

class List(
    Agilent.MassHunter.ReportBuilder.Template.IList,
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Class
    def __init__(self) -> None: ...

    DataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding  # readonly
    Hidden: bool
    Items: List[Agilent.MassHunter.ReportBuilder.Template.IReportItem]  # readonly
    PageBreak: Agilent.MassHunter.ReportBuilder.Template.BreakLocation
    _DataBinding: Agilent.MassHunter.ReportBuilder.Template.DataBinding
    _Items: List[Agilent.MassHunter.ReportBuilder.Template.ReportItem]

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class LocalizableFieldValue(
    Agilent.MassHunter.ReportBuilder.Template.IFieldValue,
    Agilent.MassHunter.ReportBuilder.Template.FieldValue,
    Agilent.MassHunter.ReportBuilder.Template.ILocalizableFieldValue,
):  # Class
    def __init__(self) -> None: ...

    Localize: bool

class Margins(Agilent.MassHunter.ReportBuilder.Template.IMargins):  # Class
    def __init__(self) -> None: ...

    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    _Bottom: Agilent.MassHunter.ReportBuilder.Template.Length
    _Left: Agilent.MassHunter.ReportBuilder.Template.Length
    _Right: Agilent.MassHunter.ReportBuilder.Template.Length
    _Top: Agilent.MassHunter.ReportBuilder.Template.Length

class Paddings(Agilent.MassHunter.ReportBuilder.Template.IPaddings):  # Class
    def __init__(self) -> None: ...

    Bottom: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    _Bottom: Agilent.MassHunter.ReportBuilder.Template.Length
    _Left: Agilent.MassHunter.ReportBuilder.Template.Length
    _Right: Agilent.MassHunter.ReportBuilder.Template.Length
    _Top: Agilent.MassHunter.ReportBuilder.Template.Length

class Page(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IPage,
):  # Class
    def __init__(self) -> None: ...

    Body: Agilent.MassHunter.ReportBuilder.Template.IBody  # readonly
    Footer: Agilent.MassHunter.ReportBuilder.Template.IFooter  # readonly
    Header: Agilent.MassHunter.ReportBuilder.Template.IHeader  # readonly
    Margins: Agilent.MassHunter.ReportBuilder.Template.IMargins  # readonly
    Orientation: Agilent.MassHunter.ReportBuilder.Template.PageOrientation
    _Body: Agilent.MassHunter.ReportBuilder.Template.Body
    _Footer: Agilent.MassHunter.ReportBuilder.Template.Footer
    _Header: Agilent.MassHunter.ReportBuilder.Template.Header
    _Margins: Agilent.MassHunter.ReportBuilder.Template.Margins

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class PageOrientation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Landscape: Agilent.MassHunter.ReportBuilder.Template.PageOrientation = (
        ...
    )  # static # readonly
    Portrait: Agilent.MassHunter.ReportBuilder.Template.PageOrientation = (
        ...
    )  # static # readonly

class PageSize(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    A4: Agilent.MassHunter.ReportBuilder.Template.PageSize = ...  # static # readonly
    Letter: Agilent.MassHunter.ReportBuilder.Template.PageSize = (
        ...
    )  # static # readonly

class PrintGraphicsSettings(
    Agilent.MassHunter.ReportBuilder.Template.IPrintGraphicsSettings
):  # Class
    def __init__(self) -> None: ...

    FitToSheet: bool
    FitToSheetWidth: bool
    Height: Agilent.MassHunter.ReportBuilder.Template.ILength
    UseTemplateSettings: bool
    Width: Agilent.MassHunter.ReportBuilder.Template.ILength

class ReportItem(Agilent.MassHunter.ReportBuilder.Template.IReportItem):  # Class
    ID: str
    Scriptable: Agilent.MassHunter.ReportBuilder.Template.IScriptable  # readonly

class ReportTemplate(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportTemplate,
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int = ...  # static # readonly

    AppVersion: str
    Copyright: str
    DefaultFonts: List[
        Agilent.MassHunter.ReportBuilder.Template.IDefaultFont
    ]  # readonly
    DesignerType: str
    EditorVersion: str
    Pages: List[Agilent.MassHunter.ReportBuilder.Template.IPage]  # readonly
    SchemaVersion: int
    TextSets: Agilent.MassHunter.ReportBuilder.Template.ITextSets  # readonly
    _DefaultFonts: List[Agilent.MassHunter.ReportBuilder.Template.DefaultFont]
    _Pages: List[Agilent.MassHunter.ReportBuilder.Template.Page]
    _TextSets: Agilent.MassHunter.ReportBuilder.Template.TextSets

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class ScriptBox(
    Agilent.MassHunter.ReportBuilder.Template.IScriptBox,
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Class
    def __init__(self) -> None: ...

    Script: str

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class Table(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.ITable,
):  # Class
    def __init__(self) -> None: ...

    Columns: List[Agilent.MassHunter.ReportBuilder.Template.ITableColumn]  # readonly
    DataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding  # readonly
    DefaultCellBorders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    Flow: bool
    HeaderRows: int
    Hidden: bool
    HorizontalAlign: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign
    KeepTogether: bool
    PageBreak: Agilent.MassHunter.ReportBuilder.Template.BreakLocation
    Rows: List[Agilent.MassHunter.ReportBuilder.Template.ITableRow]  # readonly
    SpacingBefore: Agilent.MassHunter.ReportBuilder.Template.ILength  # readonly
    WidthPercentage: float
    _Columns: List[Agilent.MassHunter.ReportBuilder.Template.TableColumn]
    _DataBinding: Agilent.MassHunter.ReportBuilder.Template.DataBinding
    _DefaultCellBorders: Agilent.MassHunter.ReportBuilder.Template.Borders
    _Rows: List[Agilent.MassHunter.ReportBuilder.Template.TableRow]
    _SpacingBefore: Agilent.MassHunter.ReportBuilder.Template.Length

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class TableCell(
    Agilent.MassHunter.ReportBuilder.Template.ITableCell,
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Class
    def __init__(self) -> None: ...

    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Borders: Agilent.MassHunter.ReportBuilder.Template.IBorders  # readonly
    ColumnSpan: int
    Content: Agilent.MassHunter.ReportBuilder.Template.IReportItem  # readonly
    _BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.Color
    _Borders: Agilent.MassHunter.ReportBuilder.Template.Borders
    _Content: Agilent.MassHunter.ReportBuilder.Template.ReportItem

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        BackgroundColor: Optional[System.Drawing.Color]

class TableColumn(Agilent.MassHunter.ReportBuilder.Template.ITableColumn):  # Class
    def __init__(self) -> None: ...

    RelativeWidth: float

class TableRow(
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
    Agilent.MassHunter.ReportBuilder.Template.ITableRow,
):  # Class
    def __init__(self) -> None: ...

    Cells: List[Agilent.MassHunter.ReportBuilder.Template.ITableCell]  # readonly
    _Cells: List[Agilent.MassHunter.ReportBuilder.Template.TableCell]

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        ...

class TextSet(Agilent.MassHunter.ReportBuilder.Template.ITextSet):  # Class
    def __init__(self) -> None: ...

    ID: str
    TextValues: List[Agilent.MassHunter.ReportBuilder.Template.ITextValue]  # readonly
    _TextValues: List[Agilent.MassHunter.ReportBuilder.Template.TextValue]

class TextSets(Agilent.MassHunter.ReportBuilder.Template.ITextSets):  # Class
    def __init__(self) -> None: ...

    Texts: List[Agilent.MassHunter.ReportBuilder.Template.ITextSet]  # readonly
    _Texts: List[Agilent.MassHunter.ReportBuilder.Template.TextSet]

class TextValue(Agilent.MassHunter.ReportBuilder.Template.ITextValue):  # Class
    def __init__(self) -> None: ...

    Culture: str
    Value: str

class Textbox(
    Agilent.MassHunter.ReportBuilder.Template.ITextbox,
    Agilent.MassHunter.ReportBuilder.Template.ReportItem,
    Agilent.MassHunter.ReportBuilder.Template.IReportItem,
):  # Class
    def __init__(self) -> None: ...

    BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    Color: Agilent.MassHunter.ReportBuilder.Template.IColor  # readonly
    ContentType: Optional[Agilent.MassHunter.ReportBuilder.Template.TextboxContentType]
    Expression: str
    FieldCaption: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    FieldFormat: Agilent.MassHunter.ReportBuilder.Template.IFieldValue  # readonly
    FieldValue: (
        Agilent.MassHunter.ReportBuilder.Template.ILocalizableFieldValue
    )  # readonly
    Font: Agilent.MassHunter.ReportBuilder.Template.IFont  # readonly
    Format: str
    HorizontalAlign: Agilent.MassHunter.ReportBuilder.Template.HorizontalAlign
    LocalizedText: str
    OutlineLevel: Optional[int]
    Paddings: Agilent.MassHunter.ReportBuilder.Template.IPaddings  # readonly
    Text: str
    VerticalAlign: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign
    _BackgroundColor: Agilent.MassHunter.ReportBuilder.Template.Color
    _Color: Agilent.MassHunter.ReportBuilder.Template.Color
    _FieldCaption: Agilent.MassHunter.ReportBuilder.Template.FieldValue
    _FieldFormat: Agilent.MassHunter.ReportBuilder.Template.FieldValue
    _FieldValue: Agilent.MassHunter.ReportBuilder.Template.LocalizableFieldValue
    _Font: Agilent.MassHunter.ReportBuilder.Template.Font
    _Paddings: Agilent.MassHunter.ReportBuilder.Template.Paddings

    # Nested Types

    class _Scriptable(Agilent.MassHunter.ReportBuilder.Template.IScriptable):  # Class
        Color: Optional[System.Drawing.Color]
        Font: Agilent.MassHunter.ReportBuilder.Template.Font._Scriptable  # readonly

class TextboxContentType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Expression: Agilent.MassHunter.ReportBuilder.Template.TextboxContentType = (
        ...
    )  # static # readonly
    FieldCaption: Agilent.MassHunter.ReportBuilder.Template.TextboxContentType = (
        ...
    )  # static # readonly
    FieldValue: Agilent.MassHunter.ReportBuilder.Template.TextboxContentType = (
        ...
    )  # static # readonly
    LocalizedText: Agilent.MassHunter.ReportBuilder.Template.TextboxContentType = (
        ...
    )  # static # readonly
    Text: Agilent.MassHunter.ReportBuilder.Template.TextboxContentType = (
        ...
    )  # static # readonly

class VerticalAlign(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Bottom: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign = (
        ...
    )  # static # readonly
    Center: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign = (
        ...
    )  # static # readonly
    Top: Agilent.MassHunter.ReportBuilder.Template.VerticalAlign = (
        ...
    )  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import IQuantDataSourceBase

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Quant.Screening

class DataSourceDesigner(
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner,
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsEdit,
):  # Class
    def __init__(self) -> None: ...

    DataSourceType: System.Type  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def GetGraphicsNames(self) -> List[str]: ...
    def GetDisplayName(self, name: str) -> str: ...
    def GetParameters(
        self, name: str
    ) -> List[
        Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceGraphicsParameter
    ]: ...
    def Dispose(self) -> None: ...
    def GetCustomUI(self) -> T: ...

class ScreeningDataSource(
    IQuantDataSourceBase,
    Agilent.MassHunter.ReportBuilder.DataSource.IDataSource,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        state: Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState,
    ) -> None: ...

    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    CompoundFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    DataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet
    )  # readonly
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    GCMode: bool
    LCMode: bool
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SampleFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )

    def DrawGraphics(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    @staticmethod
    def InitSampleResultTable(table: System.Data.DataTable) -> None: ...
    def GetFieldCaption(self, dataName: str, fieldName: str) -> str: ...
    def Select(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    @staticmethod
    def InitCompoundResultTable(table: System.Data.DataTable) -> None: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, dataName: str, fieldName: str) -> str: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import (
    IIsotopeClusterBase,
    IModificationUnit,
)
from .Agilent.MassSpectrometry.DataAnalysis.MassHunter import (
    CompoundFilterParameters,
    FilterStatus,
)
from .BasicTypes import GenericCompound, MfeCompound, Protein
from .Mathematics import RangeDouble, RangeInt

# Stubs for namespace: CompoundFilters

class AbsoluteAbundanceFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.AbsoluteAbundanceFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_minAbundace: float

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.AbsoluteAbundanceFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.AbsoluteAbundanceFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class AbundanceFilter:  # Class
    def __init__(self, p: CompoundFilters.AbundanceFilter.Parameter) -> None: ...
    def Filter(
        self, inputCompounds: List[Any]
    ) -> List[CompoundFilters.IFilterable]: ...

    # Nested Types

    class Parameter:  # Class
        def __init__(self) -> None: ...

        m_maxCount: int
        m_minAbsoluteAbundance: float
        m_minRelativeAbundance: float
        m_status: FilterStatus
        m_useHeight: bool

        Name: str  # readonly

        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...
        def FromOldFormat(self, element: System.Xml.XmlElement) -> None: ...

class ChargeStateFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.ChargeStateFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_fullRangeRequired: bool
        m_maxChargeCount: int
        m_minChargeCount: int

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.ChargeStateFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.ChargeStateFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class CommutableFilter:  # Class
    def __init__(self, parmeter: CompoundFilters.IFilterParameter) -> None: ...

    IsApplied: bool  # readonly

    def Pass(self, c: CompoundFilters.IFilterable) -> bool: ...

class CompositionFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.CompositionFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_heightVariation: float

        ElementCountRanges: Dict[str, RangeInt]
        FilterStatus: FilterStatus
        MinPeakNeeded: int  # readonly
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.CompositionFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.CompositionFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class CompoundFilterXml:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def FromXml(
        siblings: System.Xml.XmlNodeList, data: CompoundFilterParameters
    ) -> None: ...
    @staticmethod
    def ToXml(
        document: System.Xml.XmlDocument, data: CompoundFilterParameters
    ) -> System.Xml.XmlElement: ...

class CompoundFilters:  # Class
    def __init__(
        self, parameters: CompoundFilters.ICompoundFilterParameters
    ) -> None: ...

    LargeMZ: float  # static # readonly
    LargeRT: float  # static # readonly

    def FilterCompounds(self, compounds: List[MfeCompound]) -> List[MfeCompound]: ...

class GenericCompoundFilters:  # Class
    def __init__(
        self, parameters: CompoundFilters.IGenericCompoundFilterParameters
    ) -> None: ...
    def FilterCompounds(
        self, compounds: List[GenericCompound]
    ) -> List[GenericCompound]: ...

class ICompoundFilterParameters(
    CompoundFilters.IGenericCompoundFilterParameters
):  # Interface
    ChargeStateParameters: CompoundFilters.ChargeStateFilter.Parameter  # readonly
    IsotopePatternParameters: CompoundFilters.IsotopePatternFilter.Parameter  # readonly
    MinIonCountParamters: CompoundFilters.MinIonCountFilter.Parameter  # readonly
    NeutralModificationParameters: (
        CompoundFilters.NeutralModificationFilter.Parameter
    )  # readonly
    QualityScoreParameters: CompoundFilters.QualityScoreFilter.Parameter  # readonly
    TimePeakWidthParameters: CompoundFilters.PeakRtWidthFilter.Parameter  # readonly
    UunknownMassParameters: CompoundFilters.UnknownMassFilter.Parameter  # readonly

class IFilterParameter(object):  # Interface
    FilterStatus: FilterStatus  # readonly

class IFilterable(object):  # Interface
    Abundance: float  # readonly
    Height: float  # readonly
    Mass: float  # readonly
    QualityScore: float  # readonly
    RetentionTime: float  # readonly
    RetentionTimePeakWidth: float  # readonly

class IFilterableMfe(CompoundFilters.IFilterable):  # Interface
    IonCount: int  # readonly
    IsotopeClusters: Sequence[IIsotopeClusterBase]  # readonly

    def GetZStates(self) -> System.Collections.Generic.HashSet[int]: ...

class IGenericCompoundFilterParameters(object):  # Interface
    AbundanceParameters: CompoundFilters.AbundanceFilter.Parameter  # readonly
    LocationRangeParameters: CompoundFilters.LocationRangeFilter.Parameter  # readonly
    MassDefectParameters: CompoundFilters.MassDefectFilter.Parameter  # readonly
    SpecialMassParameters: CompoundFilters.SpecialMassFilter.Parameter  # readonly
    SpecialTimeParameters: CompoundFilters.SpecialTimeFilter.Parameter  # readonly

class IProteinFilterParameters(
    CompoundFilters.IGenericCompoundFilterParameters
):  # Interface
    QualityScoreParameters: CompoundFilters.QualityScoreFilter.Parameter  # readonly
    TimePeakWidthParameters: CompoundFilters.PeakRtWidthFilter.Parameter  # readonly

class IsotopePatternFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.IsotopePatternFilter.Parameter
    ) -> None: ...
    def Score(self, compound: MfeCompound) -> float: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_formula: str
        m_massAccuracyCoefficients: List[float]
        m_pattern: List[float]
        m_patternUncertainty: List[float]
        m_relativeIntensityUncertainty: float

        FilterStatus: FilterStatus  # readonly
        Name: str  # readonly
        Status: FilterStatus

        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...
        def CheckIntegraty(self) -> bool: ...

class LocationRangeFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.LocationRangeFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_massRange: RangeDouble
        m_rtRange: RangeDouble

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.LocationRangeFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.LocationRangeFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class MassDefectFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.MassDefectFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_intercept: float
        m_peptideLike: bool
        m_slope: float
        m_toleranceInterceptForNegativeDeviation: float
        m_toleranceInterceptForPositiveDeviation: float
        m_toleranceSlopeForNegativeDeviation: float
        m_toleranceSlopeForPositiveDeviation: float

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(self, other: CompoundFilters.MassDefectFilter.Parameter) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.MassDefectFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class MinIonCountFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(self, p: CompoundFilters.MinIonCountFilter.Parameter) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_minIonCount: int

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.MinIonCountFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.MinIonCountFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class NeutralModificationFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.NeutralModificationFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_modificationList: System.Collections.Generic.HashSet[IModificationUnit]

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.NeutralModificationFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.NeutralModificationFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class PeakRtWidthFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.PeakRtWidthFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_maxWidth: float
        m_minWidth: float

        FilterStatus: FilterStatus

class ProteinFilters:  # Class
    def __init__(
        self, parameters: CompoundFilters.IProteinFilterParameters
    ) -> None: ...
    def FilterProteins(self, compounds: List[Protein]) -> List[Protein]: ...

class QualityScoreFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.QualityScoreFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_maxScore: float
        m_minScore: float

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.QualityScoreFilter.Parameter
        ) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.QualityScoreFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class SpecialMassFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.SpecialMassFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(
        CompoundFilters.IFilterParameter, CompoundFilters.SpecialValueFilterParameter
    ):  # Class
        def __init__(self) -> None: ...
        def Clone(self) -> CompoundFilters.SpecialMassFilter.Parameter: ...

class SpecialTimeFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(
        self, parameter: CompoundFilters.SpecialTimeFilter.Parameter
    ) -> None: ...

    # Nested Types

    class Parameter(
        CompoundFilters.IFilterParameter, CompoundFilters.SpecialValueFilterParameter
    ):  # Class
        def __init__(self) -> None: ...

class SpecialValueFilterParameter(CompoundFilters.IFilterParameter):  # Class
    m_rangeList: List[RangeDouble]
    m_toleranceCoefficients: List[float]
    m_valueList: Sequence[float]

    FilterStatus: FilterStatus
    Name: str  # readonly

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, other: CompoundFilters.SpecialValueFilterParameter) -> bool: ...
    @staticmethod
    def RunFilter(
        theValue: float, parameter: CompoundFilters.SpecialValueFilterParameter
    ) -> bool: ...
    def GetHashCode(self) -> int: ...
    def FromXml(self, element: System.Xml.XmlElement) -> None: ...
    def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class TimeMassFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(self, parameter: CompoundFilters.TimeMassFilter.Parameter) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        m_massToleranceCoefficients: List[float]
        m_timeToleranceCoefficients: List[float]
        m_usage: CompoundFilters.TimeMassFilter.Usage
        m_valueList: List[CompoundFilters.TimeMassFilter.TimeMassData]

        FilterStatus: FilterStatus
        Name: str  # readonly

        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(self, other: CompoundFilters.TimeMassFilter.Parameter) -> bool: ...
        def GetHashCode(self) -> int: ...
        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def Clone(self) -> CompoundFilters.TimeMassFilter.Parameter: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

    class TimeMassData:  # Struct
        def __init__(self, time: float, mass: float) -> None: ...

        Mass: float
        Time: float

        def GetHashCode(self) -> int: ...
        @overload
        def Equals(self, obj: Any) -> bool: ...
        @overload
        def Equals(
            self, other: CompoundFilters.TimeMassFilter.TimeMassData
        ) -> bool: ...

    class Usage(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
        Both: CompoundFilters.TimeMassFilter.Usage = ...  # static # readonly
        MassOnly: CompoundFilters.TimeMassFilter.Usage = ...  # static # readonly
        TimeOnly: CompoundFilters.TimeMassFilter.Usage = ...  # static # readonly

class UnknownMassFilter(CompoundFilters.CommutableFilter):  # Class
    def __init__(self, p: CompoundFilters.UnknownMassFilter.Parameter) -> None: ...

    # Nested Types

    class Parameter(CompoundFilters.IFilterParameter):  # Class
        def __init__(self) -> None: ...

        FilterStatus: FilterStatus
        Name: str  # readonly

        def FromXml(self, element: System.Xml.XmlElement) -> None: ...
        def ToXml(self, doc: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    Axis,
    EqualizeMode,
    IData,
    IEquidistantData,
    ISmooth,
    NumericComparison,
    ResponseFactorCalcModeEnum,
)

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math

class CubicSpline:  # Class
    def __init__(self) -> None: ...
    def Fit(
        self,
        x: List[float],
        y: List[float],
        startSlope: float = ...,
        endSlope: float = ...,
        debug: bool = ...,
    ) -> None: ...
    def FitAndEval(
        self,
        x: List[float],
        y: List[float],
        xs: List[float],
        startSlope: float = ...,
        endSlope: float = ...,
        debug: bool = ...,
    ) -> List[float]: ...
    def Eval(self, x: List[float], debug: bool = ...) -> List[float]: ...

class DataOperations:  # Class
    def __init__(self) -> None: ...

    RelativePrecision: float = ...  # static # readonly

    @staticmethod
    def Spline(
        data: IData,
        samples: int,
        startX: Optional[float] = ...,
        endX: Optional[float] = ...,
    ) -> IEquidistantData: ...
    @staticmethod
    def ExtrapolateData(
        data: IData, rangeToExtrapolateData: List[float]
    ) -> List[float]: ...
    @staticmethod
    def ScaleLinear(data: IData, scale: float) -> IData: ...
    @staticmethod
    def Add(data1: IData, data2: IData) -> IData: ...
    @staticmethod
    def Equalize(
        data1: IData, data2: IData, mode: EqualizeMode = ...
    ) -> IEquidistantData: ...
    @staticmethod
    def Extract(data: IData, xstart: float, xend: float) -> IData: ...
    @staticmethod
    def GetYfromIndex(data: IData, index: int) -> Optional[float]: ...
    @staticmethod
    def Transform(
        data: IData, d0from: float, d1from: float, d0to: float, d1to: float, axis: Axis
    ) -> IData: ...
    @staticmethod
    def GetXfromIndex(data: IData, index: int) -> Optional[float]: ...
    @overload
    @staticmethod
    def GetYMinMax(data: IData, min: float, max: float) -> None: ...
    @overload
    @staticmethod
    def GetYMinMax(
        data: IData, min: float, max: float, inclusiveStart: int, exclusiveEnd: int
    ) -> None: ...
    @staticmethod
    def GetIndexFromXvalue(data: IData, xvalue: float) -> int: ...
    @staticmethod
    def AreConsistent(data1: IData, data2: IData) -> bool: ...
    @staticmethod
    def Sub(data1: IData, data2: IData) -> IData: ...
    @staticmethod
    def InterpolateLinear(
        t1: float, data1: IData, t2: float, data2: IData, t: float
    ) -> IData: ...
    @staticmethod
    def UnreelData(data: IData) -> IData: ...

class FloatingPointOperations:  # Class
    RelativePrecision: float = ...  # static # readonly
    RetentionTimeMaxInMinutes: float  # static # readonly
    RetentionTimeMinInMinutes: float  # static # readonly
    RetentionTimeUndefined: float  # static # readonly

    @overload
    @staticmethod
    def PearsonCorrelation(
        dataArray1: List[float],
        dataArray2: List[float],
        inclusiveStart: int,
        exclusiveEnd: int,
        noiseLevel: Optional[float],
        noiseVariance: Optional[float],
        yintercept: float,
        slope: float,
        threshold: Optional[float],
    ) -> float: ...
    @overload
    @staticmethod
    def PearsonCorrelation(
        dataArray1: List[float], dataArray2: List[float]
    ) -> float: ...
    @staticmethod
    def AreRelativeEqual(number1: float, number2: float) -> bool: ...
    @overload
    @staticmethod
    def AreNumbersEqual(
        number1: float,
        number2: float,
        comparisonMode: NumericComparison,
        precision: float,
    ) -> bool: ...
    @overload
    @staticmethod
    def AreNumbersEqual(
        number1: Optional[float],
        number2: Optional[float],
        comparisonMode: NumericComparison,
        precision: float,
    ) -> bool: ...
    @staticmethod
    def LinearNormalization(dataArray: List[float]) -> None: ...
    @staticmethod
    def ReadPercentFromString(valueToConvert: str) -> float: ...
    @overload
    @staticmethod
    def LinearRegression(
        dataArray1: List[float],
        dataArray2: List[float],
        inclusiveStart: int,
        exclusiveEnd: int,
        yintercept: float,
        slope: float,
    ) -> float: ...
    @overload
    @staticmethod
    def LinearRegression(
        dataArray1: List[float],
        dataArray2: List[float],
        inclusiveStart: int,
        exclusiveEnd: int,
        noiseLevel: Optional[float],
        noiseVariance: Optional[float],
        yintercept: float,
        slope: float,
        thres: Optional[float],
    ) -> float: ...

class LoessInterpolator(ISmooth):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, bandwidth: float, robustnessIters: int) -> None: ...

    DefaultBandwidth: float = ...  # static # readonly
    DefaultRobustnessIters: int = ...  # static # readonly

    Name: str  # readonly

    def Smooth(self, xval: List[float], yval: List[float]) -> List[float]: ...

class MathException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.ArgumentException,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...

class MathModel(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Exponential: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel = (
        ...
    )  # static # readonly
    Linear: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel = (
        ...
    )  # static # readonly
    Logarithmic: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel = (
        ...
    )  # static # readonly
    Quadratic: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel = (
        ...
    )  # static # readonly

class MathModelCoefficients:  # Class
    def __init__(self, a: float, b: float, c: float) -> None: ...

    A: float  # readonly
    B: float  # readonly
    C: float  # readonly

class MathModels:  # Class
    @staticmethod
    def ComputeRelativeResidual(
        residual: Optional[float],
        amount: Optional[float],
        response: Optional[float],
        responseFactorCalcMode: ResponseFactorCalcModeEnum,
    ) -> float: ...
    @staticmethod
    def QuadraticReverseCompute(
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        y: float,
    ) -> float: ...
    @staticmethod
    def ReverseCompute(
        mathModel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel,
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        y: float,
    ) -> float: ...
    @staticmethod
    def Compute(
        mathModel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel,
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        x: float,
    ) -> float: ...
    @staticmethod
    def GetConnectPoint(
        mathModel: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel,
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        minValue: float,
        minValueIsOnX: bool,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathPoint: ...
    @staticmethod
    def ComputeRelativeResidualPerHistoryPoint(
        modelType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel,
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        historyPointAmount: Optional[float],
        historyPointResponse: Optional[float],
        responseFactorCalcMode: ResponseFactorCalcModeEnum,
    ) -> float: ...
    @staticmethod
    def ComputeResidualPerHistoryPoint(
        modelType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModel,
        coefficients: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathModelCoefficients,
        historyPointAmount: Optional[float],
        historyPointResponse: Optional[float],
        responseFactorCalcMode: ResponseFactorCalcModeEnum,
    ) -> Optional[float]: ...

class MathPoint:  # Struct
    def __init__(self, x: float, y: float) -> None: ...

    X: float  # readonly
    Y: float  # readonly

    def GetHashCode(self) -> int: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self, other: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Math.MathPoint
    ) -> bool: ...

class SavitzkyGolay(ISmooth):  # Class
    @overload
    def __init__(self, coefficients: List[float]) -> None: ...
    @overload
    def __init__(self, coefficients: List[float], name: str) -> None: ...

    Name: str  # readonly

    @overload
    def Smooth(self, y: List[float]) -> List[float]: ...
    @overload
    def Smooth(self, x: List[float], y: List[float]) -> List[float]: ...
    @overload
    def Derive(self, x: List[float], y: List[float]) -> List[float]: ...
    @overload
    def Derive(self, xstep: float, y: List[float]) -> List[float]: ...

class SavitzkyGolayFilterCoefficients:  # Class
    Derive1stCubicNp11: List[float]  # static # readonly
    Derive1stCubicNp111: List[float]  # static # readonly
    Derive1stCubicNp13: List[float]  # static # readonly
    Derive1stCubicNp131: List[float]  # static # readonly
    Derive1stCubicNp15: List[float]  # static # readonly
    Derive1stCubicNp151: List[float]  # static # readonly
    Derive1stCubicNp17: List[float]  # static # readonly
    Derive1stCubicNp19: List[float]  # static # readonly
    Derive1stCubicNp21: List[float]  # static # readonly
    Derive1stCubicNp23: List[float]  # static # readonly
    Derive1stCubicNp25: List[float]  # static # readonly
    Derive1stCubicNp27: List[float]  # static # readonly
    Derive1stCubicNp29: List[float]  # static # readonly
    Derive1stCubicNp301: List[float]  # static # readonly
    Derive1stCubicNp31: List[float]  # static # readonly
    Derive1stCubicNp33: List[float]  # static # readonly
    Derive1stCubicNp35: List[float]  # static # readonly
    Derive1stCubicNp37: List[float]  # static # readonly
    Derive1stCubicNp39: List[float]  # static # readonly
    Derive1stCubicNp41: List[float]  # static # readonly
    Derive1stCubicNp43: List[float]  # static # readonly
    Derive1stCubicNp45: List[float]  # static # readonly
    Derive1stCubicNp47: List[float]  # static # readonly
    Derive1stCubicNp49: List[float]  # static # readonly
    Derive1stCubicNp5: List[float]  # static # readonly
    Derive1stCubicNp51: List[float]  # static # readonly
    Derive1stCubicNp53: List[float]  # static # readonly
    Derive1stCubicNp55: List[float]  # static # readonly
    Derive1stCubicNp57: List[float]  # static # readonly
    Derive1stCubicNp59: List[float]  # static # readonly
    Derive1stCubicNp69: List[float]  # static # readonly
    Derive1stCubicNp7: List[float]  # static # readonly
    Derive1stCubicNp79: List[float]  # static # readonly
    Derive1stCubicNp89: List[float]  # static # readonly
    Derive1stCubicNp9: List[float]  # static # readonly
    Derive1stCubicNp99: List[float]  # static # readonly
    SmoothNp11: List[float]  # static # readonly
    SmoothNp13: List[float]  # static # readonly
    SmoothNp15: List[float]  # static # readonly
    SmoothNp17: List[float]  # static # readonly
    SmoothNp19: List[float]  # static # readonly
    SmoothNp21: List[float]  # static # readonly
    SmoothNp23: List[float]  # static # readonly
    SmoothNp25: List[float]  # static # readonly
    SmoothNp27: List[float]  # static # readonly
    SmoothNp29: List[float]  # static # readonly
    SmoothNp3: List[float]  # static # readonly
    SmoothNp31: List[float]  # static # readonly
    SmoothNp33: List[float]  # static # readonly
    SmoothNp35: List[float]  # static # readonly
    SmoothNp37: List[float]  # static # readonly
    SmoothNp39: List[float]  # static # readonly
    SmoothNp41: List[float]  # static # readonly
    SmoothNp43: List[float]  # static # readonly
    SmoothNp45: List[float]  # static # readonly
    SmoothNp47: List[float]  # static # readonly
    SmoothNp49: List[float]  # static # readonly
    SmoothNp5: List[float]  # static # readonly
    SmoothNp51: List[float]  # static # readonly
    SmoothNp53: List[float]  # static # readonly
    SmoothNp55: List[float]  # static # readonly
    SmoothNp57: List[float]  # static # readonly
    SmoothNp59: List[float]  # static # readonly
    SmoothNp7: List[float]  # static # readonly
    SmoothNp9: List[float]  # static # readonly

class Statistical:  # Class
    @staticmethod
    def StdDeviation(x: List[float]) -> float: ...
    @overload
    @staticmethod
    def Variance(x: List[float], inclusiveStart: int, exclusiveEnd: int) -> float: ...
    @overload
    @staticmethod
    def Variance(x: List[float]) -> float: ...

class TriDiagonalMatrixF:  # Class
    def __init__(self, n: int) -> None: ...

    A: List[float]
    B: List[float]
    C: List[float]

    def __getitem__(self, row: int, col: int) -> float: ...
    def __setitem__(self, row: int, col: int, value_: float) -> None: ...
    N: int  # readonly

    def Solve(self, d: List[float]) -> List[float]: ...
    def ToDisplayString(self, fmt: str = ..., prefix: str = ...) -> str: ...
